@@ -27,7 +27,7 @@ class Filesystem(DataStorage):
 
         if "save_dataset_with_pandas" in self.args:
 
-            df.toPandas().to_csv(output_dataset, delimiter=delimiter, index=False)
+            df.toPandas().to_csv(output_dataset, sep=delimiter, index=False)
 
         else:
 
